@@ -229,9 +229,14 @@ class OrderPoint(ModelSQL, ModelView):
 
     @classmethod
     def search_rec_name(cls, name, clause):
-        return ['OR',
-            ('location.rec_name',) + tuple(clause[1:]),
-            ('product.rec_name',) + tuple(clause[1:]),
+        _, operator, value = clause
+        if operator.startswith('!') or operator.startswith('not '):
+            bool_op = 'AND'
+        else:
+            bool_op = 'OR'
+        return [bool_op,
+            ('location.rec_name', *clause[1:]),
+            ('product.rec_name', *clause[1:]),
             ]
 
     def get_location(self, name):
